@@ -7,9 +7,7 @@ static REGEXP* DOUBLE_RE = pregcomp(newSVpv("^ *([\\-\\+]?[0-9]+(?:\\.[0-9]+)?)
 static REGEXP* COMPLEX_IMAGE_ONLY_RE = pregcomp(newSVpv("^ *([\\+\\-]?[0-9]+(?:\\.[0-9]+)?)i *$", 0), 0);
 static REGEXP* COMPLEX_RE = pregcomp(newSVpv("^ *([\\+\\-]?[0-9]+(?:\\.[0-9]+)?)(?:([\\+\\-][0-9]+(?:\\.[0-9]+)?)i)? *$", 0), 0);
 
-NV Rstats::Util::pi () {
-  return 4 * Rstats::ElementFunc::atan2((NV)1, (NV)1);
-}
+NV Rstats::Util::pi () { return M_PI; }
 
 SV* Rstats::Util::args(SV* sv_names, SV* sv_args) {
   
