@@ -259,7 +259,7 @@ sub _set_seed {
 sub sapply {
   my $x1 = shift->lapply(@_);
   
-  my $x2 = Rstats::Func::c($x1->list);
+  my $x2 = Rstats::ArrayFunc::c(@{$x1->list});
   
   return $x2;
 }
@@ -268,7 +268,7 @@ sub lapply {
   my $self = shift;
   my $func_name = splice(@_, 1, 1);
   my ($x1)
-    = Rstats::Func::args(['x1'], @_);
+    = Rstats::Func::args_array(['x1'], @_);
   
   my $func = ref $func_name ? $func_name : $self->functions->{$func_name};
   
@@ -285,9 +285,10 @@ sub lapply {
 
 sub tapply {
   my $self = shift;
+
   my $func_name = splice(@_, 2, 1);
   my ($x1, $x2)
-    = Rstats::Func::args(['x1', 'x2'], @_);
+    = Rstats::Func::args_array(['x1', 'x2'], @_);
   
   my $func = ref $func_name ? $func_name : $self->functions->{$func_name};
   
@@ -306,12 +307,12 @@ sub tapply {
   # Apply
   my $new_values2 = [];
   for (my $i = 1; $i < @$new_values; $i++) {
-    my $x = $func->($new_values->[$i]);
+    my $x = $func->(Rstats::ArrayFunc::c(@{$new_values->[$i]}));
     push @$new_values2, $x;
   }
   
   my $x4_length = @$new_values2;
-  my $x4 = Rstats::Func::array($new_values2, $x4_length);
+  my $x4 = Rstats::Func::array(Rstats::ArrayFunc::c(@$new_values2), $x4_length);
   $x4->names($x2->levels);
   
   return $x4;
@@ -323,7 +324,7 @@ sub mapply {
   my $func = ref $func_name ? $func_name : $self->functions->{$func_name};
 
   my @xs = @_;
-  @xs = map { Rstats::Func::c($_) } @xs;
+  @xs = map { Rstats::ArrayFunc::c($_) } @xs;
   
   # Fix length
   my @xs_length = map { $_->length_value } @xs;
@@ -337,7 +338,7 @@ sub mapply {
   # Apply
   my $new_xs = [];
   for (my $i = 0; $i < $max_length; $i++) {
-    my @args = map { $_->vector_part($i + 1) } @xs;
+    my @args = map { $_->value($i + 1) } @xs;
     my $x = $func->(@args);
     push @$new_xs, $x;
   }
@@ -354,7 +355,7 @@ sub apply {
   my $self = shift;
   my $func_name = splice(@_, 2, 1);
   my ($x1, $x_margin)
-    = Rstats::Func::args(['x1', 'margin'], @_);
+    = Rstats::Func::args_array(['x1', 'margin'], @_);
   
   my $func = ref $func_name ? $func_name : $self->functions->{$func_name};
 
@@ -369,7 +370,7 @@ sub apply {
   my $new_elements_array = [];
   for (my $i = 0; $i < $x1_length; $i++) {
     my $index = Rstats::Util::pos_to_index($i, $dim_values);
-    my $e1 = $x1->vector_part(@$index);
+    my $e1 = $x1->value(@$index);
     my $new_index = [];
     for my $i (@$margin_values) {
       push @$new_index, $index->[$i - 1];
@@ -381,11 +382,11 @@ sub apply {
   
   my $new_elements = [];
   for my $element_array (@$new_elements_array) {
-    push @$new_elements, $func->($element_array);
+    push @$new_elements, $func->(Rstats::ArrayFunc::c(@$element_array));
   }
 
   my $x2 = Rstats::Func::NULL();
-  $x2->vector(Rstats::Func::c($new_elements)->vector);
+  $x2->vector(Rstats::ArrayFunc::c(@$new_elements)->vector);
   $x1->copy_attrs_to($x1);
   $x2->{dim} = Rstats::VectorFunc::new_integer(@$new_dim_values);
   
@@ -400,7 +401,7 @@ sub sweep {
   my $self = shift;
 
   my ($x1, $x_margin, $x2, $x_func)
-    = Rstats::Func::args(['x1', 'margin', 'x2', 'FUN'], @_);
+    = Rstats::Func::args_array(['x1', 'margin', 'x2', 'FUN'], @_);
   
   my $x_margin_values = $x_margin->values;
   my $func = defined $x_func ? $x_func->value : '-';
@@ -419,10 +420,10 @@ sub sweep {
       push @$new_index, $x1_index->[$x_margin_value - 1];
     }
     
-    my $e1 = $x2->vector_part(@{$new_index});
+    my $e1 = $x2->value(@{$new_index});
     push @$x_result_elements, $e1;
   }
-  my $x3 = Rstats::Func::c($x_result_elements);
+  my $x3 = Rstats::ArrayFunc::c(@$x_result_elements);
   
   my $x4;
   if ($func eq '+') {
