@@ -9,28 +9,10 @@ use Rstats::Vector;
 has list => sub { [] };
 has 'vector';
 
-sub is_perl_array_class {
-  my $self  = shift;
-  
-  my $is;
-  eval { $is = $self->isa('Rstats::Array') };
-  
-  return $is;
-}
-
-sub is_perl_list_class {
-  my $self  = shift;
-  
-  my $is;
-  eval { $is = $self->isa('Rstats::List') };
-  
-  return $is;
-}
-
-sub decompose_elements {
+sub decompose {
   my $self = shift;
   
-  if ($self->is_perl_array_class) {
+  if (exists $self->{vector}) {
     return $self->vector->decompose;
   }
   else {
@@ -283,7 +265,7 @@ sub _name_to_index {
 sub nlevels {
   my $self = shift;
   
-  return Rstats::Func::c($self->levels->length_value);
+  return Rstats::ArrayFunc::c($self->levels->length_value);
 }
 
 sub length {
@@ -291,14 +273,14 @@ sub length {
   
   my $length = $self->length_value;
   
-  return Rstats::Func::c($length);
+  return Rstats::ArrayFunc::c($length);
 }
 
 sub length_value {
   my $self = shift;
   
   my $length;
-  if ($self->is_perl_array_class) {
+  if (exists $self->{vector}) {
     $length = $self->vector->length_value;
   }
   else {
@@ -322,7 +304,7 @@ sub is_na {
 sub as_list {
   my $self = shift;
   
-  if ($self->is_perl_list_class) {
+  if (exists $self->{list}) {
     return $self;
   }
   else {
@@ -338,7 +320,7 @@ sub as_list {
 sub is_list {
   my $self = shift;
 
-  return $self->is_perl_list_class ? Rstats::Func::TRUE() : Rstats::Func::FALSE();
+  return exists $self->{list} ? Rstats::Func::TRUE() : Rstats::Func::FALSE();
 }
 
 sub class {
@@ -379,12 +361,12 @@ sub class {
 sub dim_as_array {
   my $x1 = shift;
   
-  if ($x1->dim->length_value) {
+  if (exists $x1->{dim}) {
     return $x1->dim;
   }
   else {
     my $length = $x1->length_value;
-    return Rstats::Func::c($length);
+    return Rstats::Func::new_double($length);
   }
 }
 
@@ -442,7 +424,7 @@ sub mode {
       croak qq/could not find function "as_$type"/;
     }
 
-    return Rstats::Func::c($mode);
+    return Rstats::ArrayFunc::c($mode);
   }
 }
 
@@ -680,7 +662,7 @@ sub values {
   my $self = shift;
   
   if (@_) {
-    $self->vector(Rstats::Func::c($_[0])->vector);
+    $self->vector(Rstats::ArrayFunc::c(@{$_[0]})->vector);
   }
   else {
     my $values = $self->vector->values;
@@ -689,82 +671,75 @@ sub values {
   }
 }
 
-sub value {
-  my $self = shift;
-  
-  my $e1 = $self->vector_part(@_);
-  
-  return defined $e1 ? $e1->value : undef;
-}
-
 sub is_vector {
   my $self = shift;
   
-  my $is = ref $self eq 'Rstats::Array' && $self->dim->length_value == 0 ? Rstats::VectorFunc::TRUE() : Rstats::VectorFunc::FALSE();
+  my $is = ref $self eq 'Rstats::Array' && !exists $self->{dim};
   
-  return Rstats::Func::c($is);
+  return Rstats::Func::new_logical($is);
 }
 
 sub is_matrix {
   my $self = shift;
 
-  my $is = ref $self eq 'Rstats::Array' && $self->dim->length_value == 2 ? Rstats::VectorFunc::TRUE() : Rstats::VectorFunc::FALSE();
+  my $x_is = ref $self eq 'Rstats::Array' && $self->dim->length_value == 2
+    ? Rstats::Func::TRUE() : Rstats::Func::FALSE();
   
-  return Rstats::Func::c($is);
+  return $x_is;
 }
 
 sub is_numeric {
   my $self = shift;
   
-  my $is = ($self->is_array || $self->is_vector) && (($self->vector->type || '') eq 'double' || ($self->vector->type || '') eq 'integer')
-    ? Rstats::VectorFunc::TRUE() : Rstats::VectorFunc::FALSE();
+  my $x_is = ($self->is_array || $self->is_vector) && (($self->vector->type || '') eq 'double' || ($self->vector->type || '') eq 'integer')
+    ? Rstats::Func::TRUE() : Rstats::Func::FALSE();
   
-  return Rstats::Func::c($is);
+  return $x_is;
 }
 
 sub is_double {
   my $self = shift;
   
-  my $is = ($self->is_array || $self->is_vector) && ($self->vector->type || '') eq 'double'
-    ? Rstats::VectorFunc::TRUE() : Rstats::VectorFunc::FALSE();
+  my $x_is = ($self->is_array || $self->is_vector) && ($self->vector->type || '') eq 'double'
+    ? Rstats::Func::TRUE() : Rstats::Func::FALSE();
   
-  return Rstats::Func::c($is);
+  return $x_is;
 }
 
 sub is_integer {
   my $self = shift;
   
-  my $is = ($self->is_array || $self->is_vector) && ($self->vector->type || '') eq 'integer'
-    ? Rstats::VectorFunc::TRUE() : Rstats::VectorFunc::FALSE();
+  my $x_is = ($self->is_array || $self->is_vector) && ($self->vector->type || '') eq 'integer'
+    ? Rstats::Func::TRUE() : Rstats::Func::FALSE();
   
-  return Rstats::Func::c($is);
+  return $x_is;
 }
 
 sub is_complex {
   my $self = shift;
   
-  my $is = ($self->is_array || $self->is_vector) && ($self->vector->type || '') eq 'complex'
-    ? Rstats::VectorFunc::TRUE() : Rstats::VectorFunc::FALSE();
+  my $x_is = ($self->is_array || $self->is_vector) && ($self->vector->type || '') eq 'complex'
+    ? Rstats::Func::TRUE() : Rstats::Func::FALSE();
   
-  return Rstats::Func::c($is);
+  return $x_is;
 }
 
 sub is_character {
   my $self = shift;
   
-  my $is = ($self->is_array || $self->is_vector) && ($self->vector->type || '') eq 'character'
-    ? Rstats::VectorFunc::TRUE() : Rstats::VectorFunc::FALSE();
+  my $x_is = ($self->is_array || $self->is_vector) && ($self->vector->type || '') eq 'character'
+    ? Rstats::Func::TRUE() : Rstats::Func::FALSE();
   
-  return Rstats::Func::c($is);
+  return $x_is;
 }
 
 sub is_logical {
   my $self = shift;
   
-  my $is = ($self->is_array || $self->is_vector) && ($self->vector->type || '') eq 'logical'
-    ? Rstats::VectorFunc::TRUE() : Rstats::VectorFunc::FALSE();
+  my $x_is = ($self->is_array || $self->is_vector) && ($self->vector->type || '') eq 'logical'
+    ? Rstats::Func::TRUE() : Rstats::Func::FALSE();
   
-  return Rstats::Func::c($is);
+  return $x_is;
 }
 
 sub is_data_frame {
@@ -778,7 +753,7 @@ sub is_array {
   
   my $is = ref $self eq 'Rstats::Array' && exists $self->{dim};
   
-  return $is;
+  return Rstats::Func::new_logical($is);
 }
 
 sub names {
